@@ -154,7 +154,10 @@ def modify_mkinitcpio_conf(partitions, root_mount_point):
             hooks.append("usr")
 
     if encrypt_hook:
-        hooks.append("encrypt")
+        if detect_plymouth():
+            hooks.append("plymouth-encrypt")
+        else:
+            hooks.append("encrypt")
         if not unencrypted_separate_boot and \
            os.path.isfile(
                os.path.join(root_mount_point, "crypto_keyfile.bin")
