@@ -1,27 +1,18 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2017-2018 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef PLASMALNFVIEWSTEP_H
 #define PLASMALNFVIEWSTEP_H
 
+#include "DllMacro.h"
 #include "utils/PluginFactory.h"
 #include "viewpages/ViewStep.h"
-#include "DllMacro.h"
 
 #include <QObject>
 #include <QUrl>
@@ -35,7 +26,7 @@ class PLUGINDLLEXPORT PlasmaLnfViewStep : public Calamares::ViewStep
 
 public:
     explicit PlasmaLnfViewStep( QObject* parent = nullptr );
-    virtual ~PlasmaLnfViewStep() override;
+    ~PlasmaLnfViewStep() override;
 
     QString prettyName() const override;
 
@@ -60,9 +51,9 @@ private:
     PlasmaLnfPage* m_widget;
     QString m_lnfPath;  // Path to the lnf tool
     QString m_themeId;  // Id of selected theme
-    QString m_liveUser; // Name of the live user (for OEM mode)
+    QString m_liveUser;  // Name of the live user (for OEM mode)
 };
 
 CALAMARES_PLUGIN_FACTORY_DECLARATION( PlasmaLnfViewStepFactory )
 
-#endif // PLASMALNFVIEWSTEP_H
+#endif  // PLASMALNFVIEWSTEP_H
